@@ -15,7 +15,7 @@ use URI::Escape qw{uri_escape_utf8};
 # of ExtUtils::MakeMaker->WriteMakefile() will accurately detect $VERSION.
 #
 my
-$VERSION = '1.000002';
+$VERSION = '1.000003';
 
 #
 # See https://tech.yandex.ru/translate/doc/dg/concepts/api-overview-docpage/
@@ -34,21 +34,22 @@ my %valid_format = map { $_ => 1 } qw { plain html };
 
 my %valid_options = map { $_ => 1 } qw { 1 };
 
-my %valid_default_ui = map { $_ => 1 } qw{ en ru };
+my %valid_default_ui = map { $_ => 1 } qw{ en ru tr };
 
 #
 # Set the default UI to Russian if the locale is Russian;
+# Set the default UI to Turkish if the locale is Turkish;
 # otherwise, set it to English.
 #
 (my $default_ui = setlocale(LC_CTYPE) || 'en') =~ s/_.*$//;
-$default_ui = 'en' if ($default_ui ne 'ru');
+$default_ui = 'en' if ($default_ui ne 'ru' || $default_ui ne 'tr');
 
 sub new
 {
     my $class = shift;
     my $self = {
         _key_        => shift,
-        _text_       => sub { my $t = shift; return (defined $t) ? uri_escape_utf8($t) : $t },
+        _text_       => uri_escape_utf8(shift),
         _from_lang_  => shift,
         _to_lang_    => shift,
         _ui_         => shift || $default_ui,
@@ -218,10 +219,12 @@ sub get_yandex_technology_reference
         my %yandex_url = (
             ru => 'http://translate.yandex.ru/',
             en => 'http://translate.yandex.com/',
+	    tr => 'http://translate.yandex.com.tr/',
         );
         my %yandex_text = (
             ru => 'Переведено сервисом Яндекс.Переводчик',
             en => 'Powered by Yandex.Translate',
+	    tr => 'Tarafından desteklenmektedir Yandex.Translate',
         );
         my $yandex_url = (exists $yandex_url{$self->{_ui_}}) ? $yandex_url{$self->{_ui_}} : $yandex_url{$default_ui};
         my $yandex_text = (exists $yandex_text{$self->{_ui_}}) ? $yandex_text{$self->{_ui_}} : $yandex_text{$default_ui};
@@ -237,11 +240,11 @@ __END__
 
 =head1 NAME
 
-Yandex::Translate - A simple API for Yandex.Translate
+Yandex::Translate - a simple API for Yandex.Translate
 
 =head1 VERSION
 
-version 1.000002
+version 1.000003
 
 =head1 SYNOPSIS
 
@@ -447,7 +450,11 @@ L<https://fossil.falseking.site/ticket>
 
 =item *
 
-James Axl C<E<lt>axlrose112@gmail.comE<gt>> , Christian Carey
+James Axl C<E<lt>axlrose112@gmail.comE<gt>>
+
+=item *
+
+Christian Carey
 
 =back
 
@@ -459,3 +466,4 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
+
